@@ -29,7 +29,7 @@
 
 #include <Akonadi/Calendar/IncidenceChanger>
 
-#include <KComboBox>
+#include <QComboBox>
 #include <KDateComboBox>
 #include <KLineEdit>
 #include <KLocalizedString>
@@ -47,15 +47,12 @@
 #include <QRadioButton>
 #include <QVBoxLayout>
 #include <QWhatsThis>
-#include <KConfigGroup>
 #include <QDialogButtonBox>
 #include <QPushButton>
 
 using namespace CalendarSupport;
 
-ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal,
-                             Akonadi::IncidenceChanger *changer,
-                             QWidget *parent)
+ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal, Akonadi::IncidenceChanger *changer, QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Archive/Delete Past Events and To-dos"));
@@ -75,7 +72,7 @@ ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal,
     mainLayout->addWidget(buttonBox);
 
     QVBoxLayout *topLayout = new QVBoxLayout(topFrame);
-    topLayout->setMargin(0);
+    topLayout->setContentsMargins(0, 0, 0, 0);
     QLabel *descLabel = new QLabel(topFrame);
     descLabel->setText(
         xi18nc("@info:whatsthis",
@@ -90,18 +87,19 @@ ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal,
               "other calendar. It is not saved in a special format, but as "
               "vCalendar."));
     descLabel->setTextInteractionFlags(
-        Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard |
-        Qt::LinksAccessibleByMouse | Qt::LinksAccessibleByKeyboard);
+        Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard
+        |Qt::LinksAccessibleByMouse | Qt::LinksAccessibleByKeyboard);
     descLabel->setWordWrap(true);
     descLabel->setContextMenuPolicy(Qt::NoContextMenu);
     topLayout->addWidget(descLabel);
     connect(descLabel, &QLabel::linkActivated, this, &ArchiveDialog::showWhatsThis);
 
     QButtonGroup *radioBG = new QButtonGroup(this);
-    connect(radioBG, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &ArchiveDialog::slotActionChanged);
+    connect(radioBG, QOverload<QAbstractButton *>::of(
+                &QButtonGroup::buttonClicked), this, &ArchiveDialog::slotActionChanged);
 
     QHBoxLayout *dateLayout = new QHBoxLayout();
-    dateLayout->setMargin(0);
+    dateLayout->setContentsMargins(0, 0, 0, 0);
     mArchiveOnceRB = new QRadioButton(i18nc("@option:radio",
                                             "Archive now items older than:"),
                                       topFrame);
@@ -133,7 +131,7 @@ ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal,
     // mExpireFolderCheckBox/mReadExpiryTimeNumInput in kmfolderdia.cpp)
     QWidget *autoArchiveHBox = new QWidget(topFrame);
     QHBoxLayout *autoArchiveHBoxHBoxLayout = new QHBoxLayout(autoArchiveHBox);
-    autoArchiveHBoxHBoxLayout->setMargin(0);
+    autoArchiveHBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     topLayout->addWidget(autoArchiveHBox);
     mAutoArchiveRB = new QRadioButton(i18nc("@option:radio",
                                             "Automaticall&y archive items older than:"),
@@ -164,7 +162,7 @@ ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal,
               "The age of the events and to-dos to archive. All older items "
               "will be saved and deleted, the newer will be kept."));
 
-    mExpiryUnitsComboBox = new KComboBox(autoArchiveHBox);
+    mExpiryUnitsComboBox = new QComboBox(autoArchiveHBox);
     autoArchiveHBoxHBoxLayout->addWidget(mExpiryUnitsComboBox);
     mExpiryUnitsComboBox->setToolTip(
         i18nc("@info:tooltip",
@@ -182,10 +180,11 @@ ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal,
     mExpiryUnitsComboBox->setEnabled(false);
 
     QHBoxLayout *fileLayout = new QHBoxLayout();
-    fileLayout->setMargin(0);
+    fileLayout->setContentsMargins(0, 0, 0, 0);
     QLabel *l = new QLabel(i18nc("@label", "Archive &file:"), topFrame);
     fileLayout->addWidget(l);
-    mArchiveFile = new KUrlRequester(QUrl::fromLocalFile(KCalPrefs::instance()->mArchiveFile), topFrame);
+    mArchiveFile = new KUrlRequester(QUrl::fromLocalFile(
+                                         KCalPrefs::instance()->mArchiveFile), topFrame);
     mArchiveFile->setMode(KFile::File);
     mArchiveFile->setFilter(i18nc("@label filter for KUrlRequester", "*.ics|iCalendar Files"));
     mArchiveFile->setToolTip(
@@ -241,7 +240,8 @@ ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal,
     topLayout->addWidget(mDeleteCb);
     connect(mDeleteCb, &QCheckBox::toggled, mArchiveFile, &KUrlRequester::setDisabled);
     connect(mDeleteCb, &QCheckBox::toggled, this, &ArchiveDialog::slotEnableUser1);
-    connect(mArchiveFile->lineEdit(), &QLineEdit::textChanged, this, &ArchiveDialog::slotEnableUser1);
+    connect(mArchiveFile->lineEdit(), &QLineEdit::textChanged, this,
+            &ArchiveDialog::slotEnableUser1);
 
     // Load settings from KCalPrefs
     mExpiryTimeNumInput->setValue(KCalPrefs::instance()->mExpiryTime);
@@ -270,7 +270,8 @@ ArchiveDialog::~ArchiveDialog()
 
 void ArchiveDialog::slotEnableUser1()
 {
-    const bool state = (mDeleteCb->isChecked() || !mArchiveFile->lineEdit()->text().trimmed().isEmpty());
+    const bool state
+        = (mDeleteCb->isChecked() || !mArchiveFile->lineEdit()->text().trimmed().isEmpty());
     mUser1Button->setEnabled(state);
 }
 
@@ -304,9 +305,9 @@ void ArchiveDialog::slotUser1()
         }
         // Force filename to be ending with vCalendar extension
         QString filename = destUrl.fileName();
-        if (!filename.endsWith(QStringLiteral(".vcs")) &&
-                !filename.endsWith(QStringLiteral(".ics"))) {
-            filename.append(QStringLiteral(".ics"));
+        if (!filename.endsWith(QLatin1String(".vcs"))
+            && !filename.endsWith(QLatin1String(".ics"))) {
+            filename.append(QLatin1String(".ics"));
             destUrl = destUrl.adjusted(QUrl::RemoveFilename);
             destUrl.setPath(destUrl.path() +  filename);
         }
@@ -338,4 +339,3 @@ void ArchiveDialog::showWhatsThis()
         QWhatsThis::showText(QCursor::pos(), widget->whatsThis());
     }
 }
-
